__all__ = ["IntrinsicsResolver", "is_intrinsics"]

from samtranslator.intrinsics.resolver import IntrinsicsResolver

from samtranslator.model.intrinsics import is_intrinsic as is_intrinsics
